@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-extension.h,v 1.3 2006/09/13 19:01:04 chpe Exp $
+ *  $Id$
  */
 
 #ifndef EPHY_ADBLOCK_EXTENSION_H
@@ -25,7 +25,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <epiphany/ephy-embed.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
