@@ -25,8 +25,8 @@
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-window.h>
+
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
@@ -62,8 +62,8 @@ EphyAutoScroller       *ephy_auto_scroller_new		 (EphyWindow *window);
 
 void			ephy_auto_scroller_start	 (EphyAutoScroller *scroller,
 							  EphyEmbed *embed,
-							  int x,
-							  int y);
+							  gdouble x,
+							  gdouble y);
 
 void			ephy_auto_scroller_stop		 (EphyAutoScroller *scroller,
 							  guint32 timestamp);
