@@ -26,7 +26,6 @@
 #include "error-viewer.h"
 #include "link-checker.h"
 #include "sgml-validator.h"
-#include "mozilla-helpers.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -39,9 +38,6 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphyErrorViewerExtension");
 
-        if (!mozilla_glue_startup ())
-              return 0;
-
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
