@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-rss-extension.h,v 1.3 2006/09/13 19:01:27 chpe Exp $
+ *  $Id$
  */
 
 #ifndef EPHY_RSS_EXTENSION_H
@@ -24,6 +24,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+typedef struct _RssUI		RssUI;
+
 /* How to contact feed readers via dbus */
 #define RSS_DBUS_SERVICE        "org.gnome.feed.Reader"
 #define RSS_DBUS_OBJECT_PATH    "/org/gnome/feed/Reader"
@@ -60,6 +62,10 @@ GType	ephy_rss_extension_get_type		(void);
 
 GType	ephy_rss_extension_register_type	(GTypeModule *module);
 
+RssUI *ephy_rss_extension_get_dialog (EphyRssExtension *extension);
+
+void ephy_rss_extension_set_dialog (EphyRssExtension *extension, RssUI *dialog);
+
 G_END_DECLS
 
 #endif
