@@ -23,7 +23,7 @@
 
 #include <glib.h>
 
-#include <epiphany/ephy-embed.h>
+#include <epiphany/epiphany.h>
 
 G_BEGIN_DECLS
 
@@ -48,8 +48,6 @@ GList	       *mozilla_get_stylesheets		(EphyEmbed *embed,
 void		mozilla_set_stylesheet		(EphyEmbed *embed,
 						 MozillaStyleSheet *style);
 
-gboolean       mozilla_glue_startup             (void);
-
 G_END_DECLS
 
 #endif /* MOZILLA_HELPERS_H */
